@@ -19,11 +19,10 @@ THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABI
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
-from __future__ import unicode_literals
 from collections import OrderedDict
 import wx
 import wx.lib.agw.supertooltip
-from ... import util
+from .. import util
 
 
 class ContextMenu(wx.Menu):
@@ -56,7 +55,7 @@ class ToolTip(wx.lib.agw.supertooltip.SuperToolTip):
     def __init__(self, target, message, header="", style="Office 2007 Blue", start_delay=.1):
         """Attach the defined tooltip to the target."""
 
-        super(ToolTip, self).__init__(message, header=header)
+        super().__init__(message, header=header)
         self.SetTarget(target)
         self.ApplyStyle(style)
         self.SetStartDelay(start_delay)
@@ -69,7 +68,7 @@ class ToolTip(wx.lib.agw.supertooltip.SuperToolTip):
             self._superToolTip.Destroy()
 
 
-class TimedStatusExtension(object):
+class TimedStatusExtension:
     """Timed status in status bar."""
 
     kill = False
@@ -90,7 +89,17 @@ class TimedStatusExtension(object):
         else:
             self.saved_text = self.GetStatusText(index)
         self.SetStatusText(text, index)
-        self.text_timer[index].Start(5000, oneShot=True)
+        self.text_timer[index].Start(3000, oneShot=True)
+
+    def cancel_timed_status(self, index=0):
+        """Cancel running timed status."""
+
+        if self.kill:
+            return
+
+        if self.text_timer[index].IsRunning():
+            self.text_timer[index].Stop()
+            self.clear_text(None, index)
 
     def sb_time_setup(self, field_count):
         """Setup timer for timed status."""
@@ -137,7 +146,7 @@ class TimedStatusExtension(object):
             count += 1
 
 
-class IconTrayExtension(object):
+class IconTrayExtension:
     """Add icon tray extension."""
 
     fields = [-1]
@@ -212,7 +221,7 @@ class IconTrayExtension(object):
         x_offset = 0
         if resize:
             platform = util.platform()
-            if platform in "osx":
+            if platform in "macos":
                 # macOS must increment by 10
                 self.SetStatusWidths([-1, len(self.sb_icons) * 20 + 10])
             elif platform == "windows":
@@ -275,7 +284,7 @@ class CustomStatusBar(wx.StatusBar, CustomStatusExtension):
         """Initialize the `CustomStatusBar` object."""
 
         field_array = [-1] if not fields else fields[:]
-        super(CustomStatusBar, self).__init__(
+        super().__init__(
             parent,
             id=wx.ID_ANY,
             style=wx.STB_DEFAULT_STYLE,
